/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*!
 * \file   imagemaker.h
 * \brief  ImageMaker is a tool for creating image files by combining document
 *         templates and style information that are read in from configuration
 *         files with run-time generated content data.
 * \author John Tarlton
 */


#ifndef _IMAGEMAKER_H
#define _IMAGEMAKER_H

#include <string>
#include <vector>
#include <map>

#include "inifile.h"

#include "style.h"
#include "element.h"
#include "document.h"



/*!
 * \class ImageMaker
 * Create image files by combining templates and styles defined by configuration
 * files with run time data.
 */
class ImageMaker
{
public:

	/* Buffer for content information. Array of element_id/content_info pairs.
	 */
	typedef std::vector<std::pair<std::string, std::string> > content_t;

	/*!
	 * ctor
	 */
	ImageMaker();

	/*!
	 * dtor
	 */
	~ImageMaker();

	/*!
	 * Load configuration.
	 * \param conf_dir - name of the directory containing document templates.
	 * \param image_dir - base directory containing the image files used for
	 *                    image elements.
	 */
	bool init( const std::string& conf_dir, const std::string& image_dir );

	/*!
	 * Create an image using the template 'id' and data 'contents' and store
	 * it in the named file.
	 * \param id  - name of the document template .
	 * \param contents - content information.
	 * \param filename - name of the resulting image file.
	 * \param width - if non-zero this overrides the width of the image.
	 * \param height - if non-zero this overrides the height of the image.
	 */
	bool create( const std::string& id,
                 const ImageMaker::content_t& contents,
                 const std::string& filename,
                 unsigned int width,
                 unsigned int height );

	/*!
	 * Lookup a document object by its id.
	 * \param id  - name of the document template .
	 */
	Document* findDocument( const std::string& id ) const;

private:

	bool loadStyle( const std::string& filename, Document& doc );

	void readStyle( const IniFile::section_data_t data, Style& style );

private:

	std::string image_dir_;

	typedef std::map<std::string, Document*> document_map_t;
	document_map_t docs_;
};


#endif // _IMAGEMAKER_H

/* vim:ts=4:set nu:
 * EOF
 */
