/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*
 * vim:set nu:ts=4:
 *
 * \file   test2.cxx
 * \brief  Test harness for ImageMakerThread.
 * \author John Tarlton
 *
 *
 * 
g++ `Magick++-config --cppflags --cxxflags --ldflags --libs` \
-o imagemaker main.cxx imagemakerthread.cxx imagemaker.cxx \
style.cxx  document.cxx element.cxx inifile.cxx string-util.cxx url.cxx -lpthread

./imagemaker "id=menu&header=Menu du Jour&items=1 Salad&items=2 Chips&items=3 Burger&items=4 Pizza&items =5 Jacket&items=6 Panini&items=7 Pasta&footer=Wednesday" image.jpeg


 */

#include <iostream>

#include <libgen.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <dirent.h>

#include "imagemakerthread.h"


const char* template_pathname = "./imagemaker.d";  /* conf files */
const char* image_pathname = "./images";           /* backgrounds etc */


/*
 * Test if 'pathname' is a directory.
 */
inline bool isDir( const std::string& pathname )
{
	struct stat st;
	return ( (lstat(pathname.c_str(), &st) == 0) && (S_ISDIR(st.st_mode)) );
}


/* 
 * Call back used to receive completion events from ImageMaker.
 */
void imagemaker_callback ( const ImageMakerThreadResponse* response ) 
{
	if ( response->ok )
	{
		std::cout << "Filename: " << response->filename << std::endl;
		std::cout << "Width: " << response->width << std::endl;
		std::cout << "Height: " << response->height << std::endl;
		std::cout << "Top: " << response->top << std::endl;
		std::cout << "Left: " << response->left << std::endl;
	}
	else
	{
		std::cout << "Failed to create image." << std::endl;
	}
}


/*
 * Creates a single image from a parameter string.
 */ 
int main( int argc, char* argv[] )
{
	if ( argc < 3 )
	{
		std::cerr << "Usage: " << basename(argv[0]) << " 'id=doc&element=value&element=value&...'  filename" << std::endl;
		return 1;
	}

	if ( !isDir(template_pathname) )
	{
		std::cerr << "Missing template directory: " << template_pathname << std::endl;
		return 1;
	}

	ImageMakerThread imagemaker(imagemaker_callback);
	imagemaker.init(template_pathname, image_pathname);

	int width = 0;
	int height = 0;
	if ( argc == 5 )
	{
		width = atoi(argv[3]);
		height = atoi(argv[4]);
		std::cout << "Height: " << height << ", width: " << width << std::endl;
	}
	imagemaker.create(argv[1], argv[2], width, height);

	sleep(1);
	imagemaker.stop();	

	return 0;
}


/* EOF */

