/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*!
 * \file   string-util.cxx
 * \brief  Utilities for manipulating strings.
 * \author John Tarlton
 */

/*------------------------------- Dependencies -------------------------------*/

#include "string-util.h"

/*----------------------------------------------------------------------------*/

/*!
 * Parse a string into a sequence of tokens
 */
void tokenise( const std::string& src,
               std::vector<std::string>& tokens,
               char delim )
{
	std::string::size_type start_pos = 0, delim_pos = 0;

	while ( std::string::npos != start_pos )
	{
		delim_pos = src.find(delim, start_pos);
		if ( std::string::npos == delim_pos )
		{
			tokens.push_back(src.substr(start_pos));
		}
		else
		{
			tokens.push_back(src.substr(start_pos, delim_pos - start_pos));
			delim_pos++;
		}
		start_pos = delim_pos;
	}
}


/*
 * remove leading and trailing spaces from a string.
 */
void trim( std::string& s )
{
	std::string::size_type pos = s.find_last_not_of("\t ");
	if ( pos != std::string::npos)
	{
		s.erase(pos + 1);
		pos = s.find_first_not_of("\t ");
		if ( pos != std::string::npos )
		{
			s.erase(0, pos);
		}
	}
	else
	{
		s.clear();
	}
}


/* vim:ts=4:set nu:
 * EOF
 */
