/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*!
 * \file   style.cxx
 * \brief  Style information for ImageMaker.
 * \author John Tarlton
 */

#include <string.h>

#include "style.h"


/* Fix build on CentOS 5.2 gcc 4.1.2 */
typedef Magick::Quantum Quantum;

#define TRANSPARENT (Magick::Color(0, 0, 0, MaxRGB))

const unsigned int CIF_HEIGHT = 288;
const unsigned int CIF_WIDTH = 352;
const unsigned int VGA_HEIGHT = 480;
const unsigned int VGA_WIDTH = 640;
const unsigned int HD720_HEIGHT = 720;
const unsigned int HD720_WIDTH = 1280;


/*
 * ctor, set some sane defaults.
 */
Style::Style()
	: height_ (HD720_HEIGHT),
	  width_ (HD720_WIDTH),
	  top_ (0),
	  left_ (0),
	  padding_ (0),
	  background_color_ (Magick::ColorRGB(0, 0, 0)),
	  color_ (Magick::ColorRGB(1.0, 1.0, 1.0)),
	  border_width_ (0),
	  border_color_ (TRANSPARENT),
	  border_radius_ (0),
	  text_align_ (Magick::NorthGravity),
	  font_size_ (24)
{
}


/*
 * dtor.
 */
Style::~Style()
{
	;
}


/*
 * Convert a named color or css-hex value to an ImageMagick color value.
 */
Magick::Color Style::makeMagickColor( const std::string& str )
{
	Magick::Color color;

	if ( str == "transparent" )
	{
		color = TRANSPARENT;
	}
	else if ( (str.length() > 0) && (str[0] == '#') )
	{
		color = cssHexColorToMagickColor(str.c_str());
	}
	else /* X11 color names */
	{
		try
		{
			color = Magick::Color(str);
		}
		catch (...)
		{
			color = TRANSPARENT;
		}
	}
	return color;
}


/*
 * Set the text alignment as a ImageMagick gravity value.
 */
void Style::setTextAlign( const std::string& alignment )
{
	if ( alignment == "center" )
	{
		text_align_ = Magick::NorthGravity;
	}
	else if ( alignment == "right" )
	{
		text_align_ = Magick::NorthEastGravity;
	}
	else /* left */
	{
		text_align_ = Magick::NorthWestGravity;
	}
}


/*
 * Set the the font size from a css named size.
 */
void Style::setFontSize( const std::string& size )
{
	if ( size == "x-small" )
	{
		font_size_ = 12;
	}
	else if ( size == "small" )
	{
		font_size_ = 16;
	}
	else if ( size == "large" )
	{
		font_size_ = 36;
	}
	else if ( size == "x-large" )
	{
		font_size_ = 48;
	}
	else if ( size == "xx-large" )
	{
		font_size_ = 72;
	}
	else /* medium */
	{
		font_size_ = 24;
	}
}


/*
 * Convert a CSS hex color string to an ImageMagick color.
 */
Magick::ColorRGB Style::cssHexColorToMagickColor( const char* rgb )
{
	if ( *rgb == '#' )
	{
		rgb++;
	}
	int r, g, b;
	if ( strlen(rgb) == 3 )
	{
		if ( sscanf(rgb, "%1x%1x%1x", &r, &g, &b) != 3 )
		{
			return Magick::ColorRGB(0, 0, 0);
		}
		r += r * 16;
		g += g * 16;
		b += b * 16;
	}
	else
	{
		if ( sscanf(rgb, "%02x%02x%02x", &r, &g, &b) != 3 )
		{
			return Magick::ColorRGB(0, 0, 0);
		}
	}

	float red = (float)r / 255.0;
	float green = (float)g / 255.0;
	float blue = (float)b / 255.0;
	return Magick::ColorRGB(red, green, blue);
}

/* vim:ts=4:set nu:
 * EOF
 */
