/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*!
 * \file   style.h
 * \brief  Style information for ImageMaker documents and their elements.
 * \author John Tarlton
 */

#ifndef _STYLE_H
#define _STYLE_H

#include <string>
#include <Magick++.h>


/*!
 * \class Style
 * Container for style infomation.
 *
 * Color strings may be defined as: a css hex value, a css color name or the
 * literal 'transparent' without the quotes.
 * See http://www.w3.org/TR/SVG/types.html#ColorKeywords for color names.
 */
class Style
{
public:

	Style();
	~Style();

	void setHeight( unsigned int px );
	unsigned int getHeight() const;

	void setWidth( unsigned int px );
	unsigned int getWidth() const;

	void setTop( unsigned int px );
	unsigned int getTop() const;

	void setLeft( unsigned int px );
	unsigned int getLeft() const;

	void setPadding( unsigned int px );
	unsigned int getPadding() const;

	void setBackgroundImage( const std::string& filename );
	const std::string& getBackgroundImage() const;

	void setBackgroundColor( const std::string& color );
	const Magick::Color& getBackgroundColor() const;

	void setColor( const std::string& color );
	const Magick::Color& getColor() const;

	void setBorderColor( const std::string& color );
	const Magick::Color& getBorderColor() const;

	void setBorderWidth( unsigned int px );
	unsigned int getBorderWidth() const;

	void setBorderRadius( unsigned int px );
	unsigned int getBorderRadius() const;

	void setTextAlign( const std::string& alignment );
	Magick::GravityType getTextAlign() const;

	void setFontSize( const std::string& size );
	unsigned int getFontSize() const ;

private:

	Magick::Color makeMagickColor( const std::string& str );
	Magick::ColorRGB cssHexColorToMagickColor( const char* rgb );

private:

	unsigned int     height_;
	unsigned int     width_;
	unsigned int     top_;
	unsigned int     left_;

	unsigned int     padding_;

	std::string      background_image_;
	Magick::Color    background_color_;

	Magick::Color    color_;

	unsigned int     border_width_;
	Magick::Color    border_color_;
	unsigned int     border_radius_;

	Magick::GravityType text_align_;

	unsigned int     font_size_;
};

////////////////////////////////////////////////////////////////////////////////

inline void Style::setHeight( unsigned int px )
{
	height_ = px;
}

inline unsigned int Style::getHeight() const
{
	return height_;
}

inline void Style::setWidth( unsigned int px )
{
	width_ = px;
}

inline unsigned int Style::getWidth() const
{
	return width_;
}

inline void Style::setTop( unsigned int px )
{
	top_ = px;
}

inline unsigned int Style::getTop() const
{
	return top_;
}

inline void Style::setLeft( unsigned int px )
{
	left_ = px;
}

inline unsigned int Style::getLeft() const
{
	return left_;
}

inline void Style::setPadding( unsigned int px )
{
	padding_ = px;
}

inline unsigned int Style::getPadding() const
{
	return padding_;
}

inline void Style::setBackgroundImage( const std::string& filename )
{
	background_image_ = filename;
}

inline const std::string& Style::getBackgroundImage() const
{
	return background_image_;
}

inline void Style::setBackgroundColor( const std::string& color )
{
	background_color_ = makeMagickColor(color);
}

inline const Magick::Color& Style::getBackgroundColor() const
{
	return background_color_;
}

inline void Style::setColor( const std::string& color )
{
	color_ = makeMagickColor(color);
}

inline const Magick::Color& Style::getColor() const
{
	return color_;
}

inline void Style::setBorderColor( const std::string& color )
{
	border_color_ = makeMagickColor(color);
}

inline const Magick::Color& Style::getBorderColor() const
{
	return border_color_;
}

inline void Style::setBorderWidth( unsigned int px )
{
	border_width_ = px;
}

inline unsigned int Style::getBorderWidth() const
{
	return border_width_;
}

inline void Style::setBorderRadius( unsigned int px )
{
	border_radius_ = px;
}

inline unsigned int Style::getBorderRadius() const
{
	return border_radius_;
}

inline Magick::GravityType Style::getTextAlign() const
{
	return text_align_;
}

inline unsigned int Style::getFontSize() const
{
	return font_size_;
}


#endif // _STYLE_H

/* vim:ts=4:set nu:
 * EOF
 */
