/**
*
* DIALOGIC CONFIDENTIAL 
* Copyright © 2012 Dialogic Inc. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to 
* the source code (collectively "Material") are owned by Dialogic Inc. and/or its subsidiaries, affiliates, suppliers
* or licensors (collectively "Dialogic"), with whom title to the Material remains. The Material contains trade secrets and proprietary
* and confidential information of Dialogic. The
* Material is protected by worldwide patent, copyright, trade secret and/or other applicable intellectual property laws and treaty
* provisions. No part of the Material may be used, copied, reproduced, 
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret and/or other intellectual 
* property right is granted to or conferred upon you by disclosure or delivery
* of the Material, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

/*!
 * \file   url.cxx
 * \brief  url decoding utility
 * \author John Tarlton
 */


#include "url.h"



/*
 * Convert an hex value specified as an ASCII character to its binary value.
 */
inline char ascii_hex_to_char( char c )
{
	if ( c >= '0' && c <= '9' )
	{
		return  c - '0';
	}
	else if ( c >= 'A' && c <= 'F' )
	{
		return c - 'A' + 10;
	}
	else if ( c >= 'a' && c <= 'f' )
	{
		return c - 'a' + 10;
	}
	return '\0';
}


/*
 * Convert a url enecoded string to plain format.
 */
bool urlDecode( const std::string& src, std::string& dst )
{
	std::string::size_type pos = 0;
	while ( pos < src.length() )
	{
		std::string::size_type escape = src.find('%', pos);

		dst.append(src.substr(pos, escape - pos));

		if ( escape == std::string::npos )
		{
			break;
		}
		if ( escape < src.length() - 2 )
		{
			char c = ascii_hex_to_char(src[escape + 1]) * 16;
			c += ascii_hex_to_char(src[escape + 2]);
			dst.push_back(c);
			pos = escape + 3;
		}
		else
		{
			return false;
		}
	}
	return true;
}


/* vim:ts=4:set nu:
 * EOF
 */
